@@ -260,125 +260,127 @@ class PromptManager:
         
         return token_distributions
            
-    def create_prompt_guide(self, pre_process=False, chunk_data=None, request=None, 
-                            instructions=None, chunk_token_distribution_number=None,
-                            chunk_number=None, total_chunks=None, notation=None,
-                            generate_title=None, request_chunks=None, 
-                            prompt_as_previous=None) -> str:
+    def create_prompt_guide(self,
+                            pre_process:bool=False,
+                            chunk_data:str=None,
+                            request:str=None,
+                            instructions:str=None,
+                            chunk_token_distribution_number:int=None,
+                            chunk_number:int=None,
+                            total_chunks:int=None,
+                            notation:str=None,
+                            generate_title:str=None,
+                            request_chunks:str=None,
+                            prompt_as_previous:str=None)->str:
         """
-        Creates a structured guide for generating prompts. The guide includes various
-        sections like request, instructions, chunk data, notation, and more.
+        This method encapsulates the process of creating formatted communication for the current data chunk,
+        which includes forming the prompt, notation, and other required fields for personalized bot communication.
+        This is returned as a formatted string.
 
         Args:
-            pre_process (bool): Flag to indicate preprocessing.
-            chunk_data (str): Data of the current chunk.
-            request (str): The user's request.
-            instructions (str): Instructions for the current iteration.
-            chunk_token_distribution_number (int): Token distribution number.
-            chunk_number (int): Current chunk number.
-            total_chunks (int): Total number of chunks.
-            notation (str): Notation from previous interactions.
-            generate_title (str): Title generated in previous steps.
-            request_chunks (str): Information about request chunks.
-            prompt_as_previous (str): Indicates if prompt is based on previous data.
+            token_dist_prompt: Token distribution information for the prompt.
+            notation (str, optional): Additional notation for the bot.
+            data_chunk (str, optional): The data chunk.
+            generate_title: Previously generated title.
+            chunk_descriptions: Descriptions of the chunks.
+            request_chunks: Previous chunk data requested.
+            select_data: Selected data.
 
         Returns:
-            str: Formatted prompt guide as a string.
+            str: A formatted communication guide.
         """
-
-        def get_delimiters() -> str:
-            return '\n' + '-' * 77 + '\n'
-
-        def get_section(title: str, data: str) -> str:
-            return f'## {title} ##\n\n{data}' if data else ''
-
-        def get_chunk_header(current_chunk: int, total_chunks: int, chunk_data: str) -> str:
-            if total_chunks in [0, '0'] or not chunk_data:
-                return ''
+        def get_delimeters()->str:
+            return '\n-----------------------------------------------------------------------------\n'
+        def get_for_prompt(title:str,data:str)->str:
+            if data:
+                return f'#{title}#'+'\n\n'+f'{data}'
+            return ''
+        def get_chunk_header(current_chunk:int,total_chunks:int,chunk_data:str)->(None or str):
+            if total_chunks in [0,'0'] or chunk_data in ['',None]:
+                return None
             current_chunk = current_chunk or 0
             try:
-                current_chunk = int(current_chunk) + 1
-            except ValueError:
+                current_chunk=int(current_chunk)+1
+            except:
                 pass
-            return f'Chunk {current_chunk} of {total_chunks}\n\n{chunk_data}'
-
+            return f'this is chunk {current_chunk} of {total_chunks}'+'\n\n'+f'{chunk_data}'
+        
+        
         if pre_process:
-            chunk_number = 0
-            total_chunks = 10
-            chunk_data = ''
-
+            chunk_number=0
+            total_chunks =10
+            chunk_data= ''
+            
         request = request or self.request_data[chunk_token_distribution_number]
         instructions = instructions or self.instruction_data[chunk_token_distribution_number]['text']
+        values_js = {'instructions':{'display':'instructions','data':instructions},
+                     'request_chunks':{'display':'previous chunk data requested','data':prompt_as_previous},
+                     'prompt':{'display':'prompt','data':request},
+                     'notation':{'display':'notation from the previous response','data':notation},
+                     'chunk_data':{'display':'chunk_data','data':get_chunk_header(chunk_number,total_chunks,chunk_data)},
+                     'prompt_as_previous':{'display':'previous module response','data':prompt_as_previous},
+                     'generate_title':{'display':'previously generated_title','data':generate_title}
+                     }
+        prompt_data_source = ''
+        self.key_check=[]
+        for key,value in values_js.items():
+            title = value['display']
+            data = value['data']
+            if data:
+                self.key_check.append(key)
+                prompt_data_source+=f"{get_delimeters()}{get_for_prompt(title,data)}"
+        return prompt_data_source
 
-        values_js = {
-            'instructions': {'title': 'Instructions', 'data': instructions},
-            'request_chunks': {'title': 'Previous Chunk Data Requested', 'data': prompt_as_previous},
-            'prompt': {'title': 'Prompt', 'data': request},
-            'notation': {'title': 'Notation', 'data': notation},
-            'chunk_data': {'title': 'Chunk Data', 'data': get_chunk_header(chunk_number, total_chunks, chunk_data)},
-            'prompt_as_previous': {'title': 'Previous Module Response', 'data': prompt_as_previous},
-            'generate_title': {'title': 'Generated Title', 'data': generate_title}
-        }
-
-        prompt_guide = ''
-        for key, value in values_js.items():
-            section = get_section(value['title'], value['data'])
-            if section:
-                prompt_guide += get_delimiters() + section
-
-        return prompt_guide
-
-    def create_prompt(self, chunk_token_distribution_number=0, chunk_number=0, 
-                      chunk_token_distribution_data=None, notation=None, 
-                      instructions=None, generate_title=None, request_chunks=None, 
-                      prompt_as_previous=None, token_adjustment=None) -> dict:
+    def create_prompt(self,
+                      chunk_token_distribution_number:int=0,
+                      chunk_number:int=0,
+                      chunk_token_distribution_data:dict=None,
+                      notation:str=None,
+                      instructions:str=None,
+                      generate_title:str=None,
+                      request_chunks:str=None,
+                      prompt_as_previous:str=None,
+                      token_adjustment:int=None)->dict:
         """
-        Forms a structured prompt for the chatbot including various components like
-        model name, issuer role, content, and other variables. It uses the 
-        create_prompt_guide method to generate the structured content.
+        This method forms a dictionary embodying the prompt for the chatbot. This includes the model name,
+        the role of the issuer, the content, and other variables. The method also takes an optional distribution number
+        and bot notation for more personalized prompts.
 
         Args:
-            chunk_token_distribution_number (int): Distribution number for the prompt.
-            chunk_number (int): Current chunk number.
-            chunk_token_distribution_data (dict): Data related to token distribution.
-            notation (str): Additional notation for the bot.
-            instructions (str): Instructions for the current iteration.
-            generate_title (str): Title generated in previous steps.
-            request_chunks (str): Information about request chunks.
-            prompt_as_previous (str): Indicates if prompt is based on previous data.
-            token_adjustment (int): Adjustment in token size if needed.
+            dist_number (int, optional): The distribution number for the prompt.
+            bot_notation (str, optional): Additional notation for the bot.
+            generate_title: Previously generated title.
+            chunk_descriptions: Descriptions of the chunks.
+            request_chunks: Previous chunk data requested.
 
         Returns:
-            dict: A dictionary representing the structured prompt.
+            dict: A dictionary representing the prompt for the chatbot.
         """
-
-        total_chunks = sum(len(chunk) for chunk in self.chunk_token_distributions)
-
-        chunk_data = self.chunk_token_distributions[chunk_token_distribution_number][chunk_number]['chunk']['data']
+        print(prompt_as_previous)
+        self.prompt_as_previous=prompt_as_previous
+        self.prompt =""
+        total_chunks =0
+        
+        for each in self.chunk_token_distributions:
+            total_chunks+=len(each)
+        chunk_token_distribution_data=self.chunk_token_distributions[chunk_token_distribution_number][chunk_number]
+        self.prompt =self.create_prompt_guide(request=self.request_data[chunk_token_distribution_number],
+                                              instructions=instructions or self.instruction_data[chunk_token_distribution_number]['text'],
+                                              chunk_token_distribution_number=chunk_token_distribution_number,
+                                              chunk_number=chunk_number,
+                                              chunk_data=chunk_token_distribution_data['chunk']['data'],
+                                              total_chunks=len(self.chunk_token_distributions[chunk_token_distribution_number]),
+                                              notation=notation,
+                                              generate_title=generate_title,
+                                              request_chunks=request_chunks,
+                                              prompt_as_previous=prompt_as_previous)
         max_tokens = chunk_token_distribution_data['completion']['available']
-
-        prompt_guide = self.create_prompt_guide(
-            request=self.request_data[chunk_token_distribution_number],
-            instructions=instructions or self.instruction_data[chunk_token_distribution_number]['text'],
-            chunk_token_distribution_number=chunk_token_distribution_number,
-            chunk_number=chunk_number,
-            chunk_data=chunk_data,
-            total_chunks=len(self.chunk_token_distributions[chunk_token_distribution_number]),
-            notation=notation,
-            generate_title=generate_title,
-            request_chunks=request_chunks,
-            prompt_as_previous=prompt_as_previous
-        )
-
-        prompt = {
-            "model": self.model_mgr.selected_model_name, 
-            "messages": [{"role": self.role or "user", "content": prompt_guide}],
-            "max_tokens": max_tokens
-        }
-
-        # Check if the prompt contains meaningful content
-        blank = all(key in ['instructions'] for key in self.key_check)
+        self.prompt ={"model": self.model_mgr.selected_model_name, "messages": [{"role": self.role or "user", "content":self.prompt }],"max_tokens": max_tokens}
+        blank = True
+        for key in self.key_check:
+            if key not in ['instructions']:
+                blank=False
         if blank:
-            prompt['blank_prompt'] = True
+            self.prompt['blank_prompt']=True
+        return self.prompt
 
-        return prompt
