@@ -114,6 +114,7 @@ class ResponseManager:
 
     def __init__(self, prompt_mgr=None, api_mgr=None, title=None, directory=None):
         self.prompt_mgr = prompt_mgr
+        self.instruction_mgr = self.prompt_mgr.instruction_mgr
         self.api_mgr = api_mgr
         self.title = title or "Untitled"
         self.directory = directory or os.path.join(os.getcwd(), 'response_data')
@@ -195,7 +196,25 @@ class ResponseManager:
     def get_abort(self):
         self.abort_js = {"abort":self.abort,"additional_responses":self.additional_responses,"request_chunks":self.request_chunks}
         
-
+    def prep_instructions_values(self,distribution_number=None):
+        self.prompt_as_previous_clone=None
+        self.distribution_number=distribution_number or self.chunk_token_distribution_number
+        self.instructions_js = self.instruction_mgr.instructions[self.distribution_number]
+        default_instructions = self.instruction_mgr.default_instructions
+        self.expected_instructions_js={}
+        for key in instructions_js.keys():
+            setattr(self,key,None)
+        for key,value in instructions_js['instructions_bools'].items():
+            if value == True:
+                example = default_instructions[key]['example']
+                if is_bool(example):
+                    value = is_bool(value,convert=True)
+                elif is_number(value):
+                    value = int(value)
+                else:
+                    value = None
+                setattr(self,key,value)
+                self.expected_instructions_js[key]=value
     def get_all_instruction(self, data: dict) -> None:
         """
         Processes all instructions from the response data and updates the relevant attributes.
@@ -204,38 +223,26 @@ class ResponseManager:
             data (dict): The response data from which instructions are extracted.
         """
         self.current_api_response = data.get('api_response', '')
-
-        # Default values
-        self.token_adjustment = 0
-        self.request_chunks = False
-        self.suggestions = None
-        self.notation = None
-        self.prompt_as_previous_clone = None
-        self.additional_responses = False
-        self.abort = False
+        self.instruction_mgr = self.prompt_mgr.instruction_mgr
+        self.prompt_as_previous_clone=None
         self.abort_js = {"abort": self.abort, "additional_responses": self.additional_responses, "request_chunks": self.request_chunks}
+        
 
         # Extract and process each instruction
         for response_key, value in data.items():
-            if response_key in self.abort_js:
-                self.abort_js[response_key] = bool(value)
-                if response_key == "abort" and value:
-                    self.break_current = True
-                continue
-
-            if response_key == "token_adjustment":
-                self.token_adjustment = int(value) if value else 0
-                continue
-
-            if value == '':
-                value = None
-
-            if response_key in ["suggestions", "notation", "generate_title"]:
+            if response_key in self.expected_instructions_js:
+                self.expected_instructions_js[response_key]
+                if is_bool(value):
+                    value = is_bool(value,convert=True)
+                elif is_number(value):
+                    value = int(value)
+                elif value == '':
+                    value = None
                 setattr(self, response_key, value)
-
-            if response_key in ["prompt_as_previous", "additional_responses", "request_chunks"]:
-                bool_value = bool(value)
-                setattr(self, response_key, bool_value)
+                if response_key in ["prompt_as_previous", "additional_responses", "request_chunks", "abort"] and value:
+                    self.break_current = True
+                if response_key in self.abort_js:
+                    self.abort_js[response_key] = bool(value)
                 if response_key == "prompt_as_previous" and bool_value:
                     self.prompt_as_previous_clone = self.current_api_response
 
@@ -244,7 +251,7 @@ class ResponseManager:
         Prepares and sends a new query to the AI model, then processes the response.
         """
         self.query_js = {}  # Resetting the query JSON
-
+        
         # Create a prompt using the PromptManager
         self.prompt = self.prompt_mgr.create_prompt(
             chunk_token_distribution_number=self.chunk_token_distribution_number,
@@ -255,7 +262,7 @@ class ResponseManager:
             token_adjustment=self.token_adjustment,
             prompt_as_previous=self.prompt_as_previous_clone
         )
-
+        self.prep_instructions_values()
         # Check for a blank prompt to avoid unnecessary requests
         if not self.prompt.get('blank_prompt'):
             self.query_js["prompt"] = self.prompt
@@ -274,7 +281,9 @@ class ResponseManager:
         """
         self.query_done = False
         self.i_query = 0
+        self.chunk_token_distribution_number=0
         self.total_dists = sum(len(dist) for dist in self.chunk_token_distributions)
+        self.prep_instructions_values(self.i_query)
         self.break_current=False
         for chunk_token_distribution_number, distributions in enumerate(self.chunk_token_distributions):
             for chunk_number, _ in enumerate(distributions):
@@ -282,6 +291,7 @@ class ResponseManager:
                 self.chunk_number = chunk_number
 
                 while not self.break_current:
+                    
                     self.send_query()
                     if self.abort or self.break_current:
                         break
